@@ -2,6 +2,7 @@
 
 from vxci.get_addons import get_module_list, get_modules2test
 from vxbase import types, net, fromenv
+from vxci.tools_test import install_chrome_commands
 import distutils.spawn
 from docker import errors, from_env
 import json
@@ -602,6 +603,10 @@ def prepare_coverage(config):
     exec_cmd(config.get('container_name'), 'apt update')
     exec_cmd(config.get('container_name'), 'apt install expect-dev tcl8.6')
 
+    for install_chrome_command in install_chrome_commands(config.get("chrome_version")):
+        exec_cmd(config.get('container_name'), install_chrome_command)
+
+
 def save_logs(config, logs):
     odoo_log = path.join(config.get('container_vol'), 'odoo.log')
     _logger.info("Save log in %s cwd %s", odoo_log, getcwd())
